from .cli import manotAI
import warnings

warnings.filterwarnings("ignore")
